@@ -5,9 +5,11 @@
 #' @param ... Currently ignored.
 #'
 #' @importFrom BayesFactor extractBF
-#' @importFrom tibble as_tibble enframe
 #' @importFrom dplyr rename select mutate
 #'
+#' @note *Important*: don't enter `1/bf_obj` to extract results for null
+#'   hypothesis; # doing so will return wrong results.
+#'
 #' @examples
 #' set.seed(123)
 #'
@@ -20,8 +22,6 @@
 #'   )
 #'
 #' # extracting Bayes Factors in a dataframe
-#' # *important*: don't enter `1/bf_obj` to extract results for null hypothesis;
-#' # doing so will return wrong results
 #' bf_extractor(bf_obj)
 #' @export
 
@@ -32,7 +32,7 @@ bf_extractor <- function(bf.object, ...) {
     logbf = FALSE,
     onlybf = FALSE
   ) %>%
-    tibble::as_tibble(.) %>%
+    as_tibble(.) %>%
     dplyr::select(.data = ., -time, -code) %>%
     dplyr::rename(.data = ., bf10 = bf) %>%
     bf_formatter(.)
@@ -40,14 +40,18 @@ bf_extractor <- function(bf.object, ...) {
 
 #' @title Prepare caption with expression for Bayes Factor results
 #' @name bf_expr
-#' @description Convenience function to write a caption message with bayes
-#'   factors in favor of the null hypothesis.
+#' @description Convenience function to create an expression with Bayes
+#'   Factor results.
 #'
 #' @param bf.df A dataframe containing two columns `log_e_bf01` (for evidence in
 #'   favor of null hypothesis) and `bf.prior`. If dataframe contains more than
 #'   two rows, only the first row will be used.
 #' @param k Number of digits after decimal point (should be an integer)
 #'   (Default: `k = 2`).
+#' @param hypothesis.text Logical that decides whether the expression containing
+#'   result should have text to describe the hypothesis test being described.
+#'   For `output = "null"`, this is `"In favor of null: "`, otherwise
+#'   `"In favor of alternative: "`.
 #' @param caption Text to display as caption (will be displayed on top of the
 #'   Bayes Factor caption/message).
 #' @param output Can either be `"null"` (or `"caption"` or `"H0"` or `"h0"`),
@@ -61,6 +65,7 @@ bf_extractor <- function(bf.object, ...) {
 #' \donttest{
 #' # for reproducibility
 #' set.seed(123)
+#' library(tidyBF)
 #'
 #' # dataframe containing results
 #' bf.df <-
@@ -72,17 +77,14 @@ bf_extractor <- function(bf.object, ...) {
 #'
 #' # creating caption (for null)
 #' bf_expr(
-#'   bf.df = bf.df,
+#'   bf.df,
 #'   output = "null",
 #'   k = 3,
 #'   caption = "Note: Iris dataset"
 #' )
 #'
 #' # creating caption (for alternative)
-#' bf_expr(
-#'   bf.df = bf.df,
-#'   output = "alternative"
-#' )
+#' bf_expr(bf.df, output = "alternative")
 #' }
 #' @export
 
@@ -90,16 +92,25 @@ bf_extractor <- function(bf.object, ...) {
 bf_expr <- function(bf.df,
                     k = 2L,
                     output = "null",
+                    hypothesis.text = TRUE,
                     caption = NULL,
                     ...) {
 
   # changing aspects of the caption based on what output is needed
   if (output %in% c("null", "caption", "H0", "h0")) {
-    hypothesis.text <- "In favor of null: "
+    # hypothesis text
+    if (isTRUE(hypothesis.text)) hypothesis.text <- "In favor of null: "
+    if (isFALSE(hypothesis.text)) hypothesis.text <- NULL
+
+    # bf-related text
     bf.value <- bf.df$log_e_bf01[[1]]
     bf.subscript <- "01"
   } else {
-    hypothesis.text <- "In favor of alternative: "
+    # hypothesis text
+    if (isTRUE(hypothesis.text)) hypothesis.text <- "In favor of alternative: "
+    if (isFALSE(hypothesis.text)) hypothesis.text <- NULL
+
+    # bf-related text
     bf.value <- -bf.df$log_e_bf01[[1]]
     bf.subscript <- "10"
   }
@@ -143,3 +154,28 @@ bf_formatter <- function(data) {
     log_10_bf01 = -1 * log_10_bf10
   )
 }
+
+
+#' @name meta_data_check
+#' @title Helper function to check column names for meta-analysis.
+#'
+#' @inheritParams bf_meta
+#'
+#' @importFrom ipmisc red blue
+#'
+#' @export
+
+meta_data_check <- function(data) {
+  # check if the two columns needed are present
+  if (sum(c("estimate", "std.error") %in% names(data)) != 2) {
+    # inform the user that skipping labels for the same reason
+    stop(message(cat(
+      ipmisc::red("Error"),
+      ipmisc::blue(": The dataframe must contain the following two columns:\n"),
+      ipmisc::blue("`estimate` and `std.error`."),
+      sep = ""
+    )),
+    call. = FALSE
+    )
+  }
+}
