@@ -31,7 +31,6 @@ ipmisc::`%$%`
 #' @importFrom ipmisc "%<-%"
 ipmisc::`%<-%`
 
-
 #' @export
 #' @importFrom rlang "%||%"
 rlang::`%||%`
@@ -41,9 +40,15 @@ rlang::`%||%`
 rlang::`%|%`
 
 #' @export
-#' @importFrom tibble tibble
-tibble::tibble
+#' @importFrom ipmisc tibble
+ipmisc::tibble
 
 #' @export
-#' @importFrom tibble as_tibble
-tibble::as_tibble
+#' @importFrom ipmisc as_tibble
+ipmisc::as_tibble
+
+# ----------------------- metaBMA -------------------------------------
+
+#' @export
+#' @importFrom metaBMA prior
+metaBMA::prior
